package MFVec2d;
use strict;
use warnings;

use rlib "./";

use MFScalar;
use base qw(MFScalar);

use SFVec2d;
our $SField = new SFVec2d;

1;
__END__
